@@ -20,8 +20,11 @@
 */
 
 #include "mainwindow.h"
+#include "config-akonadiconsole.h"
 
+#ifdef ENABLE_LIBKDEPIM
 #include <Libkdepim/UiStateSaver>
+#endif
 
 #include <KActionCollection>
 #include <KConfigGroup>
@@ -39,9 +42,9 @@ MainWindow::MainWindow(QWidget *parent)
     KStandardAction::quit(qApp, &QApplication::quit, actionCollection());
 
     setupGUI(Keys /*| ToolBar | StatusBar*/ | Save | Create, QStringLiteral("akonadiconsoleui.rc"));
-
+#ifdef ENABLE_LIBKDEPIM
     KPIM::UiStateSaver::restoreState(this, KConfigGroup(KSharedConfig::openConfig(), "UiState"));
-
+#endif
     KMessageBox::information(this, QStringLiteral("<p>Akonadi Console is purely a development tool. "
                              "It allows you to view and change internal data structures of Akonadi. "
                              "You should only change data in here if you know what you are doing, otherwise "
@@ -57,8 +60,10 @@ MainWindow::~MainWindow()
 
 void MainWindow::closeEvent(QCloseEvent *event)
 {
+#ifdef ENABLE_LIBKDEPIM
     KConfigGroup config(KSharedConfig::openConfig(), "UiState");
     KPIM::UiStateSaver::saveState(this, config);
     KSharedConfig::openConfig()->sync();
+#endif
     KXmlGuiWindow::closeEvent(event);
 }
